function [w,approx_error] = optweights_monthly_target_and_process_lastcurrentnextyear(m,rho,h,q,n,w_nonopt)

% gives the weights for the fixed-event forfecast for the CURRENT year

% We are interested in the weights for conctructing a fixed-horizon
% forecast fow a growth rate. This growth rate refers to the future level
% of a variable compared to a previous level of that variable.
%
% m is the number of high-frequency periods within one low-frequency
% period.
%
% h is the number of known observations (high-frequency) of the variable to be forecast in
% the current low-frequency period. h can take negative values, if there
% are unknown observations (due to publication lags) in the previous
% low-frequency period.
%
% q is the number of the last high-frequency period to be forecast (for the fixed-horizon forecast), counted
% from the first high-frequency period in the current year (which has the
% number 1)
%
% n is the number of periods between the first and the last high-frequency
% period for which the growth rate of the corresponding levels is to be
% forecast
%
% For example (Consensus), 
% if we are in January , and if the value of the
% previous month is known, h would equal 0. If we want to forecast inflation in December of the current year, 
% i.e. the percent change in the December level of the current year
% compared to the December level of the previous year, q would equal 12, and n would equal 12.
% if we are in February, and if the value of the
% previous month is known, h would equal 1. If we want to forecast inflation in December of the current year, 
% i.e. the percent change in the December level of the current year
% compared to the December level of the previous year, q would equal 12, and n would equal 12.
% if we are in February, and if the value of the
% previous month is known, h would equal 1. If we want to forecast inflation in October of the current year, 
% i.e. the percent change in the October level of the current year
% compared to the October level of the previous year, q would equal 10, and n would equal 12.
% etc


% Covariance matrix of the 1- to m-step-ahead forecasts an AR(1)-process
% with AR-parameter rho and E(u^2) = 1-rho^2, so that variable has variance
% equal to 1
% calculation of sigsq is not necessary for the weights, because sigsq cancels out
% at the end, but it is important for the size of the approximation error

sigsq = 1;
% Construct maxtrix of autocovariances of an AR(1)-process with
% AR-parameter rho
covarvec = ( rho.^abs(-(4*m-1):(4*m-1)) )';
Omega_data = NaN(4*m,4*m);
for i = 1:(4*m)
    Omega_data(:,i) = covarvec( 4*m-i + 1 : 2*(4*m)-i );
end
Omega_data = sigsq * Omega_data;

Omega_f = sigsq* (rho.^(1:4*m))' * (rho.^(1:4*m));

Omega_hyb = Omega_data;
s = 2*m - h;
Omega_hyb( 4*m-s+1 : 4*m , 4*m-s+1 :4*m ) = Omega_f(1:s,1:s);

Omega = rot90(Omega_hyb,2);



% Patton-Timmermann weights
omegak = NaN(2*m,1);
for i = 1:(2*m)
    omegak(i) = 1 - abs(i-m)/m;
end

B1 = [zeros(1,m) zeros(1,m) omegak']; % previous year
B2 = [zeros(1,m) omegak' zeros(1,m)]; % current year
B3 = [omegak' zeros(1,m) zeros(1,m)]; % next year



Aq = [zeros(1,2*m-q) m/n*ones(1,n) zeros(1,m+q-n) zeros(1,m)];
%disp(Aq);

M = Aq - B3;
%M = Aq - 1  * B2;
N1 = B3 - B1;
N2 = B3 - B2;
N = [N2 ; N1]; % 1st weight will be for N2, i.e. for current year

if nargin == 5 
    w = -( M * Omega * N') / ( N * Omega * N');
elseif nargin == 6
    w = w_nonopt;
end

%approx_error = N*Omega*N'*w^2 + 2*M*Omega*N'*w + M*Omega*M';
approx_error = (M + w*N) * Omega * (M + w*N)' ;





    