function [w,approx_error] = optweights_ARp(m,rhovec,h,q,n,w_nonopt)

% gives the weights for the fixed-event forfecast for the CURRENT year

% We are interested in the weights for conctructing a fixed-horizon
% forecast fow a growth rate. This growth rate refers to the future level
% of a variable compared to a previous level of that variable.
%
% m is the number of high-frequency periods within one low-frequency
% period.
%
% h is the number of known observations (high-frequency) of the variable to be forecast in
% the current low-frequency period. h can take negative values, if there
% are unknown observations (due to publication lags) in the previous
% low-frequency period.
%
% q is the number of the last high-frequency period to be forecast (for the fixed-horizon forecast), counted
% from the first high-frequency period in the current year (which has the
% number 1)
%
% n is the number of periods between the first and the last high-frequency
% period for which the growth rate of the corresponding levels is to be
% forecast
%
% For example (Consensus), 
% if we are in January , and if the value of the
% previous month is known, h would equal 0. If we want to forecast inflation in December of the current year, 
% i.e. the percent change in the December level of the current year
% compared to the December level of the previous year, q would equal 12, and n would equal 12.
% if we are in February, and if the value of the
% previous month is known, h would equal 1. If we want to forecast inflation in December of the current year, 
% i.e. the percent change in the December level of the current year
% compared to the December level of the previous year, q would equal 12, and n would equal 12.
% if we are in February, and if the value of the
% previous month is known, h would equal 1. If we want to forecast inflation in October of the current year, 
% i.e. the percent change in the October level of the current year
% compared to the October level of the previous year, q would equal 10, and n would equal 12.
% etc



% Covariance matrix of the 1- to m-step-ahead forecasts an AR(p)-process
% with AR-parameters rhovec and E(u^2) set such that variable has variance
% equal to 1
% calculation of sigsq is not necessary for the weights, because sigsq cancels out
% at the end, but it is important for the size of the approximation error

% Construct maxtrix of autocovariances of an AR(p)-process with
% AR-parameters as in rhovec
number_ma_coefs = 500; % the higher this number, the better is the approximation the AR(p)-process by the MA(number_ma_coefs) coefs.
                       % With AR(1), rho = 0.98, number_ma_coefs=500, the
                       % 500th MA-coef equals 0.00004. With rho = 0.97,
                       % it's 0.0000002.
thetas = [1 ; ar_coefs_to_ma(rhovec,number_ma_coefs,number_ma_coefs)];
% covariance of observations
for i = 1:3*m
    lagi = i-1;
    acv_obs(i,1) = sum(thetas(1:end-lagi).*thetas(1+lagi:end));
end
acr = acv_obs/acv_obs(1,1);
om_obs_prel = zeros(m+h,m+h);
for i = 1:(m+h-1)
    om_obs_prel(i+1:end,i) = acr(2:m+h-i+1);
end
om_obs =om_obs_prel + om_obs_prel' + eye(m+h);
if h < 2*m
    % covariance of forecasts
    for covlag = 0:(3*m-(m+h)-1) 
        for i = 1:(3*m-(m+h)-covlag)         
            forecastlag  = (3*m-(m+h)+1) - i - covlag;
            acv_fore(i+covlag,i) = sum(thetas(1+forecastlag:end-covlag).*thetas(1+forecastlag+covlag:end));
        end
    end
    acr_fore_prel = acv_fore/acv_obs(1,1);
    om_fore = tril(acr_fore_prel,-1) + acr_fore_prel'; 
    
    Om_prel = zeros(3*m,3*m);
    Om_prel(1:2*m-h,1:2*m-h) = om_fore;
    Om_prel(2*m-h+1:3*m,2*m-h+1:3*m) = om_obs;       
    % covariance of forecasts and observations
    Om_prel2 = zeros(3*m,3*m);
    acr_rev = (acr(end:-1:1))';
    for j = 1:m+h
        Om_prel2(2*m-h+j,1:2*m-h) = acr_rev(m+h+1-j:end-j);
    end
    Om_prel2 = Om_prel2 + Om_prel2';
    Omega = Om_prel + Om_prel2;
else
    Omega = om_obs;
end


% Patton-Timmermann weights
omegak = NaN(2*m,1);
for i = 1:(2*m)
    omegak(i) = 1 - abs(i-m)/m;
end

B1 = [zeros(1,m) omegak'];
B2 = [omegak' zeros(1,m)];



Aq = [zeros(1,2*m-q) m/n*ones(1,n) zeros(1,m+q-n)];
%disp(Aq);

M = Aq - B2;
%M = Aq - 1  * B2;
N = B2 - B1;

if nargin == 5 
    w = -( M * Omega * N') / ( N * Omega * N');
elseif nargin == 6
    w = w_nonopt;
end

%approx_error = N*Omega*N'*w^2 + 2*M*Omega*N'*w + M*Omega*M';

approx_error = (M + w*N) * Omega * (M + w*N)' ;





    