function [w,approx_error] = optweights_quarterly_target_monthly_process(m,rho,h,q,mm,nn,w_nonopt)

% Consensus Example: You are in March, you know the value from February, you want the
% growth rate of Q1 next year (last month to be forecast = 15) compared to Q1 current year (nn=4). Then you type (iid process):
% [w,approx_error] = optweights_hybnew_medfreq_target(12,0,2,15,4,4)
% This gives the weight for the forecast of the NEXT year

% Works like optweights_hybnew, but considers the case of a
% medium-frequency target like a quarterly target for the fixed-horizon
% forecast, when the forecasts are made on a monthly basis and the
% fixed-event forecasts have an anuual target. The major  difference wrt to optweights_hybnew
% is the need to specify mm. This is only required for the construction of
% Aq below.

% We are interested in the weights for conctructing a fixed-horizon
% forecast fow a growth rate. This growth rate refers to the future level
% of a variable compared to a previous level of that variable.
%
% h is the number of known observations (high-frequency) of the variable to be forecast in
% the current low-frequency period. h can take negative values, if there
% are unknown observations (due to publication lags) in the previous
% low-frequency period.
%
% q is the number of the last high-frequency period to be forecast (for the fixed-horizon forecast), counted
% from the first high-frequency period in the current year (which has the
% number 1)
%
% mm is the frequency of the medium-frequency target. In the case of a
% quartely target, mm = 4;
%
% nn is the number of periods between the first and the last medium-frequency
% period for which the growth rate of the corresponding levels is to be
% forecast
%
% For example (Consensus), 
% if we are in January , and if the value of the
% previous month is known, h would equal 0. If we want to forecast inflation in Q4 of the current year, 
% i.e. the percent change in the Q4 level of the current year
% compared to the Q4 level of the previous year, q would equal 12 (the number of the last month in Q4, December), and nn would equal 4.
% if we are in February, and if the value of the
% previous month is known, h would equal 1. If we want to forecast inflation in Q4 of the current year, 
% i.e. the percent change in the Q4 level of the current year
% compared to the Q4 level of the previous year, q would equal 12, and nn would equal 4.
% if we are in February, and if the value of the
% previous month is known, h would equal 1. If we want to forecast inflation in Q3 of the current year, 
% i.e. the percent change in the Q3 level of the current year
% compared to the Q3 level of the previous year, q would equal 9, and nn would equal 4.
% etc



% Covariance matrix of the 1- to m-step-ahead forecasts and realizations of an AR(1)-process with AR-parameter rho and E(u^2) = 1
% calculation of sigsq is not really necessary, because sigsq cancels out
% at the end
%sigsq = (1-rho^2);
sigsq = 1;
% Construct maxtrix of autocovariances of an AR(1)-process with
% AR-parameter rho
covarvec = ( rho.^abs(-(3*m-1):(3*m-1)) )';
Omega_data = NaN(3*m,3*m);
for i = 1:(3*m)
    Omega_data(:,i) = covarvec( 3*m-i + 1 : 2*(3*m)-i );
end
Omega_data = sigsq * Omega_data;

Omega_forecasts = sigsq* (rho.^(1:3*m))' * (rho.^(1:3*m));

Omega_hyb = Omega_data;
s = 2*m - h;
Omega_hyb( 3*m-s+1 : 3*m , 3*m-s+1 :3*m ) = Omega_forecasts(1:s,1:s);


Omega = rot90(Omega_hyb,2);
%disp(Omega);


%disp(Omega);

% Patton-Timmermann weights
omegak = NaN(2*m,1);
for i = 1:(2*m)
    omegak(i) = 1 - abs(i-m)/m;
end

B = [omegak' zeros(1,m)];
C = [zeros(1,m) omegak'];

% What is the number of the last medium-frequency period to be forecast (Q1 current year = 1, Q2 current year = 2 etc)?
% months per quarter
mpq  = m/mm;
%disp(mpq);
if ceil(mpq)~=mpq
    disp('Error in values supplied to function! m/mm must be an integer');
end
lmfp = ceil(q/mpq);
% What is the number of the first medium-frequency period to be forecast (Q1 current year = 1, Q2 current year = 2 etc)?
%fmfp = lmfp - n/mpq;
if ceil(q/mpq)~=q/mpq
    disp('Error in values supplied to function! n/(m/mm) must be an integer');
    disp('if you want to forecast, say, the 3rd quarter of the current year');
    disp('q must be set to q=9, because September is the LAST month in Q3');
end

omegak2 = NaN(2*mpq,1);
for i = 1:(2*mpq)
    omegak2(i) = 1 - abs(i-mpq)/mpq;
end

n = nn*mpq;
Aq = [zeros(1,2*m-q) omegak2(1:mpq)' ones(1,n - mpq) omegak2(mpq+1:2*mpq)' zeros(1,m+q-n-mpq)];
%disp(Aq);
%Aq = [zeros(1,2*m-q) ones(1,n) zeros(1,m+q-n)];
%disp(Aq);

M = Aq - B;
N = B - C;

if nargin == 6 
    w = -( M * Omega * N') / ( N * Omega * N');
elseif nargin == 7
    w = w_nonopt;
end

approx_error = N*Omega*N'*w^2 + 2*M*Omega*N'*w + M*Omega*M';





    